@@ -11,6 +11,7 @@
 #   limitations under the License.
 
 import os, sys, zipfile, _jcc2
+from itertools import izip
 
 python_ver = '%d.%d.%d' %(sys.version_info[0:3])
 if python_ver < '2.4':
@@ -62,6 +63,13 @@ class InvalidArgsError(Exception):
     pass
 
 
+class RequiredPackageError(Exception):
+
+    def __str__(self):
+        return "%s is required, please add a --package declaration for it, " \
+               "or its parameters, to the JCC invocation." %(self.args[0])
+
+
 _jcc2._set_exception_types(JavaError, InvalidArgsError)
 from _jcc2 import findClass as _findClass
 from _jcc2 import *
@@ -81,6 +89,53 @@ def findClass(className):
     return cls
 
 
+# fix for PYLUCENE-47: method overloads need to be sorted deterministically
+# and heuristically by the so-called rank of their parameter types, trying
+# to match parameters whose classes are deeper in the class hierarchy first
+def sortSignatures(signatures, groupByName=False):
+    def _compare(sig0, sig1):
+        # group signatures by name, lexicographically
+        if groupByName:
+            diff = cmp(sig0.getName(), sig1.getName())
+            if diff != 0:
+                return diff
+
+        sig0_types = sig0.getParameterTypes()
+        sig1_types = sig1.getParameterTypes()
+
+        # group signatures by number of parameters, lowest first
+        diff = len(sig0_types) - len(sig1_types)
+        if diff != 0:
+            return diff
+
+        def _getRank(types):
+            rank = 0
+            for item in types:
+                while item is not None:
+                    rank += 1
+                    item = item.getSuperclass()
+            return rank
+        
+        # sort signatures of equal length by the sum of class ranks
+        # so that deepest classes are considered first during calls,
+        # thus sort highest rank number first
+        diff = _getRank(sig1_types) - _getRank(sig0_types)
+        if diff != 0:
+            return diff
+
+        # sort signatures of equal rank by the names of their classes
+        # lexicographically
+        for (sig0_type, sig1_type) in izip(sig0_types, sig1_types):
+            diff = cmp(sig0_type.getName(), sig1_type.getName())
+            if diff != 0:
+                return diff
+
+        # give up, sig1 must be larger ;-)
+        return -1
+            
+    sort(signatures, fn=_compare)
+
+
 INDENT = '  '
 HALF_INDENT = ' '
 
@@ -555,17 +610,20 @@ def jcc(args):
     initvm_args['maxstack'] = '512k'
     initvm_args['vmargs'] = vmargs
 
-    env = initVM(os.pathsep.join(classpath) or None, **initvm_args)
-
-    typeset = set()
-    excludes = set(excludes)
-
     if imports:
         if shared:
             imports = dict((__import__(import_), set()) for import_ in imports)
         else:
             raise ValueError, "--shared must be used when using --import"
 
+        for import_ in imports.iterkeys():
+            classpath.append(import_.CLASSPATH)
+
+    env = initVM(os.pathsep.join(classpath) or None, **initvm_args)
+
+    typeset = set()
+    excludes = set(excludes)
+
     if recompile or not build and (install or dist or egg_info):
         if moduleName is None:
             raise ValueError, 'module name not specified (use --python)'
@@ -587,7 +645,6 @@ def jcc(args):
                             className = className.replace(os.path.sep, '/')
                         importset.add(findClass(className))
             for import_, importset in imports.iteritems():
-                env._addClassPath(import_.CLASSPATH)
                 include = os.path.join(import_.__dir__, 'include')
                 os.path.walk(include, walk, (include, importset))
                 typeset.update(importset)
@@ -760,6 +817,9 @@ def header(env, out, cls, typeset, packages, excludes, generics,
                 interfaces.append(interface)
                 if pt is not None:
                     for ta in pt.getActualTypeArguments():
+                        if not known(ta, typeset, declares, packages,
+                                     excludes, True):
+                            raise RequiredPackageError(ta)
                         addRequiredTypes(ta, typeset, True)
     else:
         for interface in cls.getInterfaces():
@@ -779,8 +839,10 @@ def header(env, out, cls, typeset, packages, excludes, generics,
         if generics:
             for clsParam in getTypeParameters(cls):
                 if Class.instance_(clsParam):
+                    if not known(clsParam, typeset, declares, packages,
+                                 excludes, True):
+                        raise RequiredPackageError(clsParam)
                     addRequiredTypes(clsParam, typeset, True)
-                    known(clsParam, typeset, declares, packages, excludes, True)
     else:
         superClsName = 'JObject'
 
@@ -814,7 +876,7 @@ def header(env, out, cls, typeset, packages, excludes, generics,
                     break
             else:
                 constructors.append(constructor)
-    sort(constructors, key=lambda x: len(x.getParameterTypes()))
+    sortSignatures(constructors)
 
     methods = {}
     protectedMethods = []
@@ -850,14 +912,8 @@ def header(env, out, cls, typeset, packages, excludes, generics,
         elif Modifier.isProtected(modifiers):
             protectedMethods.append(method)
 
-    def _compare(m0, m1):
-        value = cmp(m0.getName(), m1.getName())
-        if value == 0:
-            value = len(m0.getParameterTypes()) - len(m1.getParameterTypes())
-        return value
-
     methods = methods.values()
-    sort(methods, fn=_compare)
+    sortSignatures(methods, groupByName=True)
     methodNames = set([cppname(method.getName()) for method in methods])
 
     for constructor in constructors:
