@@ -419,7 +419,9 @@ public class TestBackwardsCompatibility extends LuceneTestCase {
     "9.4.2-cfs",
     "9.4.2-nocfs",
     "9.5.0-cfs",
-    "9.5.0-nocfs"
+    "9.5.0-nocfs",
+    "9.6.0-cfs",
+    "9.6.0-nocfs"
   };
 
   public static String[] getOldNames() {
@@ -459,7 +461,8 @@ public class TestBackwardsCompatibility extends LuceneTestCase {
     "sorted.9.4.0",
     "sorted.9.4.1",
     "sorted.9.4.2",
-    "sorted.9.5.0"
+    "sorted.9.5.0",
+    "sorted.9.6.0"
   };
 
   public static String[] getOldSortedNames() {
