@@ -16,6 +16,17 @@
  */
 package org.apache.lucene.codecs.simpletext;
 
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.DOC;
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.END;
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.END_OFFSET;
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.FIELD;
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.FREQ;
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.PAYLOAD;
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.POS;
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.START_OFFSET;
+import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.TERM;
+import static org.apache.lucene.codecs.simpletext.SimpleTextSkipWriter.SKIP_LIST;
+
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
 import java.util.Collection;
@@ -24,7 +35,6 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.TreeMap;
-
 import org.apache.lucene.codecs.FieldsProducer;
 import org.apache.lucene.index.BaseTermsEnum;
 import org.apache.lucene.index.FieldInfo;
@@ -53,31 +63,16 @@ import org.apache.lucene.util.IOUtils;
 import org.apache.lucene.util.IntsRefBuilder;
 import org.apache.lucene.util.RamUsageEstimator;
 import org.apache.lucene.util.StringHelper;
-import org.apache.lucene.util.fst.Builder;
 import org.apache.lucene.util.fst.BytesRefFSTEnum;
 import org.apache.lucene.util.fst.FST;
+import org.apache.lucene.util.fst.FSTCompiler;
 import org.apache.lucene.util.fst.PairOutputs;
 import org.apache.lucene.util.fst.PositiveIntOutputs;
 import org.apache.lucene.util.fst.Util;
 
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.DOC;
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.END;
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.END_OFFSET;
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.FIELD;
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.FREQ;
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.PAYLOAD;
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.POS;
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.START_OFFSET;
-import static org.apache.lucene.codecs.simpletext.SimpleTextFieldsWriter.TERM;
-import static org.apache.lucene.codecs.simpletext.SimpleTextSkipWriter.SKIP_LIST;
-
 class SimpleTextFieldsReader extends FieldsProducer {
 
-  private static final long BASE_RAM_BYTES_USED =
-      RamUsageEstimator.shallowSizeOfInstance(SimpleTextFieldsReader.class)
-          + RamUsageEstimator.shallowSizeOfInstance(TreeMap.class);
-
-  private final TreeMap<String,Long> fields;
+  private final TreeMap<String, Long> fields;
   private final IndexInput in;
   private final FieldInfos fieldInfos;
   private final int maxDoc;
@@ -85,7 +80,11 @@ class SimpleTextFieldsReader extends FieldsProducer {
   public SimpleTextFieldsReader(SegmentReadState state) throws IOException {
     this.maxDoc = state.segmentInfo.maxDoc();
     fieldInfos = state.fieldInfos;
-    in = state.directory.openInput(SimpleTextPostingsFormat.getPostingsFileName(state.segmentInfo.name, state.segmentSuffix), state.context);
+    in =
+        state.directory.openInput(
+            SimpleTextPostingsFormat.getPostingsFileName(
+                state.segmentInfo.name, state.segmentSuffix),
+            state.context);
     boolean success = false;
     try {
       fields = readFields(in.clone());
@@ -97,10 +96,10 @@ class SimpleTextFieldsReader extends FieldsProducer {
     }
   }
 
-  private TreeMap<String,Long> readFields(IndexInput in) throws IOException {
+  private TreeMap<String, Long> readFields(IndexInput in) throws IOException {
     ChecksumIndexInput input = new BufferedChecksumIndexInput(in);
     BytesRefBuilder scratch = new BytesRefBuilder();
-    TreeMap<String,Long> fields = new TreeMap<>();
+    TreeMap<String, Long> fields = new TreeMap<>();
 
     while (true) {
       SimpleTextUtil.readLine(input, scratch);
@@ -108,7 +107,12 @@ class SimpleTextFieldsReader extends FieldsProducer {
         SimpleTextUtil.checkFooter(input);
         return fields;
       } else if (StringHelper.startsWith(scratch.get(), FIELD)) {
-        String fieldName = new String(scratch.bytes(), FIELD.length, scratch.length() - FIELD.length, StandardCharsets.UTF_8);
+        String fieldName =
+            new String(
+                scratch.bytes(),
+                FIELD.length,
+                scratch.length() - FIELD.length,
+                StandardCharsets.UTF_8);
         fields.put(fieldName, input.getFilePointer());
       }
     }
@@ -161,7 +165,7 @@ class SimpleTextFieldsReader extends FieldsProducer {
               PairOutputs.Pair<PairOutputs.Pair<Long, Long>, PairOutputs.Pair<Long, Long>>>
           result = fstEnum.seekCeil(text);
       if (result == null) {
-        //System.out.println("  end");
+        // System.out.println("  end");
         return SeekStatus.END;
       } else {
         // System.out.println("  got text=" + term.utf8ToString());
@@ -175,10 +179,10 @@ class SimpleTextFieldsReader extends FieldsProducer {
         totalTermFreq = pair2.output2;
 
         if (result.input.equals(text)) {
-          //System.out.println("  match docsStart=" + docsStart);
+          // System.out.println("  match docsStart=" + docsStart);
           return SeekStatus.FOUND;
         } else {
-          //System.out.println("  not match docsStart=" + docsStart);
+          // System.out.println("  not match docsStart=" + docsStart);
           return SeekStatus.NOT_FOUND;
         }
       }
@@ -237,7 +241,9 @@ class SimpleTextFieldsReader extends FieldsProducer {
       if (hasPositions && PostingsEnum.featureRequested(flags, PostingsEnum.POSITIONS)) {
 
         SimpleTextPostingsEnum docsAndPositionsEnum;
-        if (reuse != null && reuse instanceof SimpleTextPostingsEnum && ((SimpleTextPostingsEnum) reuse).canReuse(SimpleTextFieldsReader.this.in)) {
+        if (reuse != null
+            && reuse instanceof SimpleTextPostingsEnum
+            && ((SimpleTextPostingsEnum) reuse).canReuse(SimpleTextFieldsReader.this.in)) {
           docsAndPositionsEnum = (SimpleTextPostingsEnum) reuse;
         } else {
           docsAndPositionsEnum = new SimpleTextPostingsEnum();
@@ -246,7 +252,9 @@ class SimpleTextFieldsReader extends FieldsProducer {
       }
 
       SimpleTextDocsEnum docsEnum;
-      if (reuse != null && reuse instanceof SimpleTextDocsEnum && ((SimpleTextDocsEnum) reuse).canReuse(SimpleTextFieldsReader.this.in)) {
+      if (reuse != null
+          && reuse instanceof SimpleTextDocsEnum
+          && ((SimpleTextDocsEnum) reuse).canReuse(SimpleTextFieldsReader.this.in)) {
         docsEnum = (SimpleTextDocsEnum) reuse;
       } else {
         docsEnum = new SimpleTextDocsEnum();
@@ -343,7 +351,7 @@ class SimpleTextFieldsReader extends FieldsProducer {
       }
       boolean first = true;
       int termFreq = 0;
-      while(true) {
+      while (true) {
         final long lineStart = in.getFilePointer();
         SimpleTextUtil.readLine(in, scratch);
         if (StringHelper.startsWith(scratch.get(), DOC)) {
@@ -354,12 +362,12 @@ class SimpleTextFieldsReader extends FieldsProducer {
             }
             return docID;
           }
-          scratchUTF16.copyUTF8Bytes(scratch.bytes(), DOC.length, scratch.length()-DOC.length);
+          scratchUTF16.copyUTF8Bytes(scratch.bytes(), DOC.length, scratch.length() - DOC.length);
           docID = ArrayUtil.parseInt(scratchUTF16.chars(), 0, scratchUTF16.length());
           termFreq = 0;
           first = false;
         } else if (StringHelper.startsWith(scratch.get(), FREQ)) {
-          scratchUTF16.copyUTF8Bytes(scratch.bytes(), FREQ.length, scratch.length()-FREQ.length);
+          scratchUTF16.copyUTF8Bytes(scratch.bytes(), FREQ.length, scratch.length() - FREQ.length);
           termFreq = ArrayUtil.parseInt(scratchUTF16.chars(), 0, scratchUTF16.length());
         } else if (StringHelper.startsWith(scratch.get(), POS)) {
           // skip termFreq++;
@@ -468,7 +476,8 @@ class SimpleTextFieldsReader extends FieldsProducer {
       nextDocStart = fp;
       docID = -1;
       readPositions = indexOptions.compareTo(IndexOptions.DOCS_AND_FREQS_AND_POSITIONS) >= 0;
-      readOffsets = indexOptions.compareTo(IndexOptions.DOCS_AND_FREQS_AND_POSITIONS_AND_OFFSETS) >= 0;
+      readOffsets =
+          indexOptions.compareTo(IndexOptions.DOCS_AND_FREQS_AND_POSITIONS_AND_OFFSETS) >= 0;
       if (!readOffsets) {
         startOffset = -1;
         endOffset = -1;
@@ -499,22 +508,22 @@ class SimpleTextFieldsReader extends FieldsProducer {
       boolean first = true;
       in.seek(nextDocStart);
       long posStart = 0;
-      while(true) {
+      while (true) {
         final long lineStart = in.getFilePointer();
         SimpleTextUtil.readLine(in, scratch);
-        //System.out.println("NEXT DOC: " + scratch.utf8ToString());
+        // System.out.println("NEXT DOC: " + scratch.utf8ToString());
         if (StringHelper.startsWith(scratch.get(), DOC)) {
           if (!first) {
             nextDocStart = lineStart;
             in.seek(posStart);
             return docID;
           }
-          scratchUTF16.copyUTF8Bytes(scratch.bytes(), DOC.length, scratch.length()-DOC.length);
+          scratchUTF16.copyUTF8Bytes(scratch.bytes(), DOC.length, scratch.length() - DOC.length);
           docID = ArrayUtil.parseInt(scratchUTF16.chars(), 0, scratchUTF16.length());
           tf = 0;
           first = false;
         } else if (StringHelper.startsWith(scratch.get(), FREQ)) {
-          scratchUTF16.copyUTF8Bytes(scratch.bytes(), FREQ.length, scratch.length()-FREQ.length);
+          scratchUTF16.copyUTF8Bytes(scratch.bytes(), FREQ.length, scratch.length() - FREQ.length);
           tf = ArrayUtil.parseInt(scratchUTF16.chars(), 0, scratchUTF16.length());
           posStart = in.getFilePointer();
         } else if (StringHelper.startsWith(scratch.get(), POS)) {
@@ -563,8 +572,9 @@ class SimpleTextFieldsReader extends FieldsProducer {
     public int nextPosition() throws IOException {
       if (readPositions) {
         SimpleTextUtil.readLine(in, scratch);
-        assert StringHelper.startsWith(scratch.get(), POS): "got line=" + scratch.get().utf8ToString();
-        scratchUTF16_2.copyUTF8Bytes(scratch.bytes(), POS.length, scratch.length()-POS.length);
+        assert StringHelper.startsWith(scratch.get(), POS)
+            : "got line=" + scratch.get().utf8ToString();
+        scratchUTF16_2.copyUTF8Bytes(scratch.bytes(), POS.length, scratch.length() - POS.length);
         pos = ArrayUtil.parseInt(scratchUTF16_2.chars(), 0, scratchUTF16_2.length());
       } else {
         pos = -1;
@@ -572,13 +582,17 @@ class SimpleTextFieldsReader extends FieldsProducer {
 
       if (readOffsets) {
         SimpleTextUtil.readLine(in, scratch);
-        assert StringHelper.startsWith(scratch.get(), START_OFFSET): "got line=" + scratch.get().utf8ToString();
-        scratchUTF16_2.copyUTF8Bytes(scratch.bytes(), START_OFFSET.length, scratch.length()-START_OFFSET.length);
+        assert StringHelper.startsWith(scratch.get(), START_OFFSET)
+            : "got line=" + scratch.get().utf8ToString();
+        scratchUTF16_2.copyUTF8Bytes(
+            scratch.bytes(), START_OFFSET.length, scratch.length() - START_OFFSET.length);
         startOffset = ArrayUtil.parseInt(scratchUTF16_2.chars(), 0, scratchUTF16_2.length());
         SimpleTextUtil.readLine(in, scratch);
-        assert StringHelper.startsWith(scratch.get(), END_OFFSET): "got line=" + scratch.get().utf8ToString();
-        scratchUTF16_2.grow(scratch.length()-END_OFFSET.length);
-        scratchUTF16_2.copyUTF8Bytes(scratch.bytes(), END_OFFSET.length, scratch.length()-END_OFFSET.length);
+        assert StringHelper.startsWith(scratch.get(), END_OFFSET)
+            : "got line=" + scratch.get().utf8ToString();
+        scratchUTF16_2.grow(scratch.length() - END_OFFSET.length);
+        scratchUTF16_2.copyUTF8Bytes(
+            scratch.bytes(), END_OFFSET.length, scratch.length() - END_OFFSET.length);
         endOffset = ArrayUtil.parseInt(scratchUTF16_2.chars(), 0, scratchUTF16_2.length());
       }
 
@@ -640,6 +654,7 @@ class SimpleTextFieldsReader extends FieldsProducer {
       RamUsageEstimator.shallowSizeOfInstance(SimpleTextTerms.class)
           + RamUsageEstimator.shallowSizeOfInstance(BytesRef.class)
           + RamUsageEstimator.shallowSizeOfInstance(CharsRef.class);
+
   private class SimpleTextTerms extends Terms implements Accountable {
     private final long termsStart;
     private final FieldInfo fieldInfo;
@@ -661,14 +676,14 @@ class SimpleTextFieldsReader extends FieldsProducer {
 
     private void loadTerms() throws IOException {
       PositiveIntOutputs posIntOutputs = PositiveIntOutputs.getSingleton();
-      final Builder<
+      final FSTCompiler<
               PairOutputs.Pair<PairOutputs.Pair<Long, Long>, PairOutputs.Pair<Long, Long>>>
           fstCompiler;
       final PairOutputs<Long, Long> outputsOuter = new PairOutputs<>(posIntOutputs, posIntOutputs);
       final PairOutputs<Long, Long> outputsInner = new PairOutputs<>(posIntOutputs, posIntOutputs);
       final PairOutputs<PairOutputs.Pair<Long, Long>, PairOutputs.Pair<Long, Long>> outputs =
           new PairOutputs<>(outputsOuter, outputsInner);
-      fstCompiler = new Builder<>(FST.INPUT_TYPE.BYTE1, outputs);
+      fstCompiler = new FSTCompiler<>(FST.INPUT_TYPE.BYTE1, outputs);
       IndexInput in = SimpleTextFieldsReader.this.in.clone();
       in.seek(termsStart);
       final BytesRefBuilder lastTerm = new BytesRefBuilder();
@@ -678,7 +693,7 @@ class SimpleTextFieldsReader extends FieldsProducer {
       long skipPointer = 0;
       FixedBitSet visitedDocs = new FixedBitSet(maxDoc);
       final IntsRefBuilder scratchIntsRef = new IntsRefBuilder();
-      while(true) {
+      while (true) {
         SimpleTextUtil.readLine(in, scratch);
         if (scratch.get().equals(END) || StringHelper.startsWith(scratch.get(), FIELD)) {
           if (lastDocsStart != -1) {
@@ -694,11 +709,11 @@ class SimpleTextFieldsReader extends FieldsProducer {
           docFreq++;
           sumDocFreq++;
           totalTermFreq++;
-          scratchUTF16.copyUTF8Bytes(scratch.bytes(), DOC.length, scratch.length()-DOC.length);
+          scratchUTF16.copyUTF8Bytes(scratch.bytes(), DOC.length, scratch.length() - DOC.length);
           int docID = ArrayUtil.parseInt(scratchUTF16.chars(), 0, scratchUTF16.length());
           visitedDocs.set(docID);
         } else if (StringHelper.startsWith(scratch.get(), FREQ)) {
-          scratchUTF16.copyUTF8Bytes(scratch.bytes(), FREQ.length, scratch.length()-FREQ.length);
+          scratchUTF16.copyUTF8Bytes(scratch.bytes(), FREQ.length, scratch.length() - FREQ.length);
           totalTermFreq += ArrayUtil.parseInt(scratchUTF16.chars(), 0, scratchUTF16.length()) - 1;
         } else if (StringHelper.startsWith(scratch.get(), SKIP_LIST)) {
           skipPointer = in.getFilePointer();
@@ -723,20 +738,22 @@ class SimpleTextFieldsReader extends FieldsProducer {
         }
       }
       docCount = visitedDocs.cardinality();
-      fst = fstCompiler.finish();
+      fst = fstCompiler.compile();
       /*
       PrintStream ps = new PrintStream("out.dot");
       fst.toDot(ps);
       ps.close();
       System.out.println("SAVED out.dot");
       */
-      //System.out.println("FST " + fst.sizeInBytes());
+      // System.out.println("FST " + fst.sizeInBytes());
     }
 
     @Override
     public long ramBytesUsed() {
-      return TERMS_BASE_RAM_BYTES_USED + (fst!=null ? fst.ramBytesUsed() : 0)
-          + RamUsageEstimator.sizeOf(scratch.bytes()) + RamUsageEstimator.sizeOf(scratchUTF16.chars());
+      return TERMS_BASE_RAM_BYTES_USED
+          + (fst != null ? fst.ramBytesUsed() : 0)
+          + RamUsageEstimator.sizeOf(scratch.bytes())
+          + RamUsageEstimator.sizeOf(scratchUTF16.chars());
     }
 
     @Override
@@ -750,7 +767,16 @@ class SimpleTextFieldsReader extends FieldsProducer {
 
     @Override
     public String toString() {
-      return getClass().getSimpleName() + "(terms=" + termCount + ",postings=" + sumDocFreq + ",positions=" + sumTotalTermFreq + ",docs=" + docCount + ")";
+      return getClass().getSimpleName()
+          + "(terms="
+          + termCount
+          + ",postings="
+          + sumDocFreq
+          + ",positions="
+          + sumTotalTermFreq
+          + ",docs="
+          + docCount
+          + ")";
     }
 
     @Override
@@ -789,7 +815,10 @@ class SimpleTextFieldsReader extends FieldsProducer {
 
     @Override
     public boolean hasOffsets() {
-      return fieldInfo.getIndexOptions().compareTo(IndexOptions.DOCS_AND_FREQS_AND_POSITIONS_AND_OFFSETS) >= 0;
+      return fieldInfo
+              .getIndexOptions()
+              .compareTo(IndexOptions.DOCS_AND_FREQS_AND_POSITIONS_AND_OFFSETS)
+          >= 0;
     }
 
     @Override
@@ -808,10 +837,10 @@ class SimpleTextFieldsReader extends FieldsProducer {
     return Collections.unmodifiableSet(fields.keySet()).iterator();
   }
 
-  private final Map<String,SimpleTextTerms> termsCache = new HashMap<>();
+  private final Map<String, SimpleTextTerms> termsCache = new HashMap<>();
 
   @Override
-  synchronized public Terms terms(String field) throws IOException {
+  public synchronized Terms terms(String field) throws IOException {
     SimpleTextTerms terms = termsCache.get(field);
     if (terms == null) {
       Long fp = fields.get(field);
@@ -835,20 +864,6 @@ class SimpleTextFieldsReader extends FieldsProducer {
     in.close();
   }
 
-  @Override
-  public synchronized long ramBytesUsed() {
-    long sizeInBytes = BASE_RAM_BYTES_USED + fields.size() * 2 * RamUsageEstimator.NUM_BYTES_OBJECT_REF;
-    for(SimpleTextTerms simpleTextTerms : termsCache.values()) {
-      sizeInBytes += (simpleTextTerms!=null) ? simpleTextTerms.ramBytesUsed() : 0;
-    }
-    return sizeInBytes;
-  }
-
-  @Override
-  public synchronized Collection<Accountable> getChildResources() {
-    return Accountables.namedAccountables("field", termsCache);
-  }
-
   @Override
   public String toString() {
     return getClass().getSimpleName() + "(fields=" + fields.size() + ")";
